/*******************************************************************************
* File Name: DPWM.h  
* Version 3.0
*
* Description:
*  Contains the prototypes and constants for the functions available to the 
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_PWM_DPWM_H)
#define CY_PWM_DPWM_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 DPWM_initVar;


/***************************************
* Conditional Compilation Parameters
***************************************/
#define DPWM_Resolution 16u
#define DPWM_UsingFixedFunction 0u
#define DPWM_DeadBandMode 0u
#define DPWM_KillModeMinTime 0u
#define DPWM_KillMode 0u
#define DPWM_PWMMode 0u
#define DPWM_PWMModeIsCenterAligned 0u
#define DPWM_DeadBandUsed 0u
#define DPWM_DeadBand2_4 0u

#if !defined(DPWM_PWMUDB_genblk8_stsreg__REMOVED)
    #define DPWM_UseStatus 1u
#else
    #define DPWM_UseStatus 0u
#endif /* !defined(DPWM_PWMUDB_genblk8_stsreg__REMOVED) */

#if !defined(DPWM_PWMUDB_genblk1_ctrlreg__REMOVED)
    #define DPWM_UseControl 1u
#else
    #define DPWM_UseControl 0u
#endif /* !defined(DPWM_PWMUDB_genblk1_ctrlreg__REMOVED) */
#define DPWM_UseOneCompareMode 1u
#define DPWM_MinimumKillTime 1u
#define DPWM_EnableMode 0u

#define DPWM_CompareMode1SW 0u
#define DPWM_CompareMode2SW 0u

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component PWM_v3_0 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */

/* Use Kill Mode Enumerated Types */
#define DPWM__B_PWM__DISABLED 0
#define DPWM__B_PWM__ASYNCHRONOUS 1
#define DPWM__B_PWM__SINGLECYCLE 2
#define DPWM__B_PWM__LATCHED 3
#define DPWM__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define DPWM__B_PWM__DBMDISABLED 0
#define DPWM__B_PWM__DBM_2_4_CLOCKS 1
#define DPWM__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define DPWM__B_PWM__ONE_OUTPUT 0
#define DPWM__B_PWM__TWO_OUTPUTS 1
#define DPWM__B_PWM__DUAL_EDGE 2
#define DPWM__B_PWM__CENTER_ALIGN 3
#define DPWM__B_PWM__DITHER 5
#define DPWM__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define DPWM__B_PWM__LESS_THAN 1
#define DPWM__B_PWM__LESS_THAN_OR_EQUAL 2
#define DPWM__B_PWM__GREATER_THAN 3
#define DPWM__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define DPWM__B_PWM__EQUAL 0
#define DPWM__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct
{
    
    uint8 PWMEnableState;
       
    #if(!DPWM_UsingFixedFunction)
        uint16 PWMUdb;               /* PWM Current Counter value  */
        #if(!DPWM_PWMModeIsCenterAligned)
            uint16 PWMPeriod;
        #endif /* (!DPWM_PWMModeIsCenterAligned) */
        #if (DPWM_UseStatus)
            uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
        #endif /* (DPWM_UseStatus) */
        
        /* Backup for Deadband parameters */
        #if(DPWM_DeadBandMode == DPWM__B_PWM__DBM_256_CLOCKS || \
            DPWM_DeadBandMode == DPWM__B_PWM__DBM_2_4_CLOCKS)
            uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
        #endif /* deadband count is either 2-4 clocks or 256 clocks */
        
        /* Backup Kill Mode Counter*/
        #if(DPWM_KillModeMinTime)
            uint8 PWMKillCounterPeriod; /* Kill Mode period value */
        #endif /* (DPWM_KillModeMinTime) */
       
        /* Backup control register */
        #if(DPWM_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif /* (DPWM_UseControl) */
        
    #endif /* (!DPWM_UsingFixedFunction) */
   
}DPWM_backupStruct;


/***************************************
*        Function Prototypes
 **************************************/
 
void    DPWM_Start(void) ;
void    DPWM_Stop(void) ;

#if (DPWM_UseStatus || DPWM_UsingFixedFunction)
    void  DPWM_SetInterruptMode(uint8 interruptMode) ;
    uint8 DPWM_ReadStatusRegister(void) ;
#endif /* (DPWM_UseStatus || DPWM_UsingFixedFunction) */

#define DPWM_GetInterruptSource() DPWM_ReadStatusRegister()

#if (DPWM_UseControl)
    uint8 DPWM_ReadControlRegister(void) ; 
    void  DPWM_WriteControlRegister(uint8 control) ;
#endif /* (DPWM_UseControl) */

#if (DPWM_UseOneCompareMode)
   #if (DPWM_CompareMode1SW)
       void    DPWM_SetCompareMode(uint8 comparemode) ;
   #endif /* (DPWM_CompareMode1SW) */
#else
    #if (DPWM_CompareMode1SW)
        void    DPWM_SetCompareMode1(uint8 comparemode) ;
    #endif /* (DPWM_CompareMode1SW) */
    #if (DPWM_CompareMode2SW)
        void    DPWM_SetCompareMode2(uint8 comparemode) ;
    #endif /* (DPWM_CompareMode2SW) */
#endif /* (DPWM_UseOneCompareMode) */

#if (!DPWM_UsingFixedFunction)
    uint16   DPWM_ReadCounter(void) ;
    uint16 DPWM_ReadCapture(void) ;
    
	#if (DPWM_UseStatus)
	        void DPWM_ClearFIFO(void) ;
	#endif /* (DPWM_UseStatus) */

    void    DPWM_WriteCounter(uint16 counter) ;
#endif /* (!DPWM_UsingFixedFunction) */

void    DPWM_WritePeriod(uint16 period) ;
uint16 DPWM_ReadPeriod(void) ;

#if (DPWM_UseOneCompareMode)
    void    DPWM_WriteCompare(uint16 compare) ;
    uint16 DPWM_ReadCompare(void) ; 
#else
    void    DPWM_WriteCompare1(uint16 compare) ;
    uint16 DPWM_ReadCompare1(void) ; 
    void    DPWM_WriteCompare2(uint16 compare) ;
    uint16 DPWM_ReadCompare2(void) ; 
#endif /* (DPWM_UseOneCompareMode) */


#if (DPWM_DeadBandUsed)
    void    DPWM_WriteDeadTime(uint8 deadtime) ;
    uint8   DPWM_ReadDeadTime(void) ;
#endif /* (DPWM_DeadBandUsed) */

#if ( DPWM_KillModeMinTime)
    void DPWM_WriteKillTime(uint8 killtime) ;
    uint8 DPWM_ReadKillTime(void) ; 
#endif /* ( DPWM_KillModeMinTime) */

void DPWM_Init(void) ;
void DPWM_Enable(void) ;
void DPWM_Sleep(void) ;
void DPWM_Wakeup(void) ;
void DPWM_SaveConfig(void) ;
void DPWM_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define DPWM_INIT_PERIOD_VALUE        399u
#define DPWM_INIT_COMPARE_VALUE1      0u
#define DPWM_INIT_COMPARE_VALUE2      63u
#define DPWM_INIT_INTERRUPTS_MODE     (uint8)(((uint8)(0u << DPWM_STATUS_TC_INT_EN_MASK_SHIFT)) | \
                                                  (uint8)((uint8)(0u << DPWM_STATUS_CMP2_INT_EN_MASK_SHIFT)) | \
                                                  (uint8)((uint8)(0u << DPWM_STATUS_CMP1_INT_EN_MASK_SHIFT )) | \
                                                  (uint8)((uint8)(0u << DPWM_STATUS_KILL_INT_EN_MASK_SHIFT )))
#define DPWM_DEFAULT_COMPARE2_MODE    (uint8)((uint8)1u << DPWM_CTRL_CMPMODE2_SHIFT)
#define DPWM_DEFAULT_COMPARE1_MODE    (uint8)((uint8)4u << DPWM_CTRL_CMPMODE1_SHIFT)
#define DPWM_INIT_DEAD_TIME           1u


/********************************
*         Registers
******************************** */

#if (DPWM_UsingFixedFunction)
   #define DPWM_PERIOD_LSB          (*(reg16 *) DPWM_PWMHW__PER0)
   #define DPWM_PERIOD_LSB_PTR      ( (reg16 *) DPWM_PWMHW__PER0)
   #define DPWM_COMPARE1_LSB        (*(reg16 *) DPWM_PWMHW__CNT_CMP0)
   #define DPWM_COMPARE1_LSB_PTR    ( (reg16 *) DPWM_PWMHW__CNT_CMP0)
   #define DPWM_COMPARE2_LSB        0x00u
   #define DPWM_COMPARE2_LSB_PTR    0x00u
   #define DPWM_COUNTER_LSB         (*(reg16 *) DPWM_PWMHW__CNT_CMP0)
   #define DPWM_COUNTER_LSB_PTR     ( (reg16 *) DPWM_PWMHW__CNT_CMP0)
   #define DPWM_CAPTURE_LSB         (*(reg16 *) DPWM_PWMHW__CAP0)
   #define DPWM_CAPTURE_LSB_PTR     ( (reg16 *) DPWM_PWMHW__CAP0)
   #define DPWM_RT1                 (*(reg8 *)  DPWM_PWMHW__RT1)
   #define DPWM_RT1_PTR             ( (reg8 *)  DPWM_PWMHW__RT1)
      
#else
   #if (DPWM_Resolution == 8u) /* 8bit - PWM */
	   
	   #if(DPWM_PWMModeIsCenterAligned)
	       #define DPWM_PERIOD_LSB      (*(reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__D1_REG)
	       #define DPWM_PERIOD_LSB_PTR   ((reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__D1_REG)
	   #else
	       #define DPWM_PERIOD_LSB      (*(reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__F0_REG)
	       #define DPWM_PERIOD_LSB_PTR   ((reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__F0_REG)
	   #endif /* (DPWM_PWMModeIsCenterAligned) */
	   
	   #define DPWM_COMPARE1_LSB    (*(reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__D0_REG)
	   #define DPWM_COMPARE1_LSB_PTR ((reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__D0_REG)
	   #define DPWM_COMPARE2_LSB    (*(reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__D1_REG)
	   #define DPWM_COMPARE2_LSB_PTR ((reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__D1_REG)
	   #define DPWM_COUNTERCAP_LSB   (*(reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__A1_REG)
	   #define DPWM_COUNTERCAP_LSB_PTR ((reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__A1_REG)
	   #define DPWM_COUNTER_LSB     (*(reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__A0_REG)
	   #define DPWM_COUNTER_LSB_PTR  ((reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__A0_REG)
	   #define DPWM_CAPTURE_LSB     (*(reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__F1_REG)
	   #define DPWM_CAPTURE_LSB_PTR  ((reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__F1_REG)
   
   #else
   		#if(CY_PSOC3) /* 8-bit address space */	
			#if(DPWM_PWMModeIsCenterAligned)
		       #define DPWM_PERIOD_LSB      (*(reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__D1_REG)
		       #define DPWM_PERIOD_LSB_PTR   ((reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__D1_REG)
		    #else
		       #define DPWM_PERIOD_LSB      (*(reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__F0_REG)
		       #define DPWM_PERIOD_LSB_PTR   ((reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__F0_REG)
		    #endif /* (DPWM_PWMModeIsCenterAligned) */
		   
		    #define DPWM_COMPARE1_LSB    (*(reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__D0_REG)
		    #define DPWM_COMPARE1_LSB_PTR ((reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__D0_REG)
		    #define DPWM_COMPARE2_LSB    (*(reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__D1_REG)
		    #define DPWM_COMPARE2_LSB_PTR ((reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__D1_REG)
		    #define DPWM_COUNTERCAP_LSB   (*(reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__A1_REG)
		    #define DPWM_COUNTERCAP_LSB_PTR ((reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__A1_REG)
		    #define DPWM_COUNTER_LSB     (*(reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__A0_REG)
		    #define DPWM_COUNTER_LSB_PTR  ((reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__A0_REG)
		    #define DPWM_CAPTURE_LSB     (*(reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__F1_REG)
		    #define DPWM_CAPTURE_LSB_PTR  ((reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__F1_REG)
		#else
			#if(DPWM_PWMModeIsCenterAligned)
		       #define DPWM_PERIOD_LSB      (*(reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__16BIT_D1_REG)
		       #define DPWM_PERIOD_LSB_PTR   ((reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__16BIT_D1_REG)
		    #else
		       #define DPWM_PERIOD_LSB      (*(reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__16BIT_F0_REG)
		       #define DPWM_PERIOD_LSB_PTR   ((reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__16BIT_F0_REG)
		    #endif /* (DPWM_PWMModeIsCenterAligned) */
		   
		    #define DPWM_COMPARE1_LSB    (*(reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__16BIT_D0_REG)
		    #define DPWM_COMPARE1_LSB_PTR ((reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__16BIT_D0_REG)
		    #define DPWM_COMPARE2_LSB    (*(reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__16BIT_D1_REG)
		    #define DPWM_COMPARE2_LSB_PTR ((reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__16BIT_D1_REG)
		    #define DPWM_COUNTERCAP_LSB   (*(reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__16BIT_A1_REG)
		    #define DPWM_COUNTERCAP_LSB_PTR ((reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__16BIT_A1_REG)
		    #define DPWM_COUNTER_LSB     (*(reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__16BIT_A0_REG)
		    #define DPWM_COUNTER_LSB_PTR  ((reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__16BIT_A0_REG)
		    #define DPWM_CAPTURE_LSB     (*(reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__16BIT_F1_REG)
		    #define DPWM_CAPTURE_LSB_PTR  ((reg16 *) DPWM_PWMUDB_sP16_pwmdp_u0__16BIT_F1_REG)
		#endif
		
	   #define DPWM_AUX_CONTROLDP1    (*(reg8 *) DPWM_PWMUDB_sP16_pwmdp_u1__DP_AUX_CTL_REG)
       #define DPWM_AUX_CONTROLDP1_PTR  ((reg8 *) DPWM_PWMUDB_sP16_pwmdp_u1__DP_AUX_CTL_REG)

   #endif /* (DPWM_Resolution == 8) */
   
   #define DPWM_AUX_CONTROLDP0      (*(reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__DP_AUX_CTL_REG)
   #define DPWM_AUX_CONTROLDP0_PTR  ((reg8 *) DPWM_PWMUDB_sP16_pwmdp_u0__DP_AUX_CTL_REG)

#endif /* (DPWM_UsingFixedFunction) */
   
#if(DPWM_KillModeMinTime )
    #define DPWM_KILLMODEMINTIME      (*(reg8 *) DPWM_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define DPWM_KILLMODEMINTIME_PTR   ((reg8 *) DPWM_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif /* (DPWM_KillModeMinTime ) */

#if(DPWM_DeadBandMode == DPWM__B_PWM__DBM_256_CLOCKS)
    #define DPWM_DEADBAND_COUNT      (*(reg8 *) DPWM_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define DPWM_DEADBAND_COUNT_PTR  ((reg8 *) DPWM_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define DPWM_DEADBAND_LSB_PTR    ((reg8 *) DPWM_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define DPWM_DEADBAND_LSB        (*(reg8 *) DPWM_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(DPWM_DeadBandMode == DPWM__B_PWM__DBM_2_4_CLOCKS)
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (DPWM_UsingFixedFunction)
        #define DPWM_DEADBAND_COUNT        (*(reg8 *) DPWM_PWMHW__CFG0) 
        #define DPWM_DEADBAND_COUNT_PTR     ((reg8 *) DPWM_PWMHW__CFG0)
        #define DPWM_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << DPWM_DEADBAND_COUNT_SHIFT)
        /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */
        #define DPWM_DEADBAND_COUNT_SHIFT   0x06u  
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define DPWM_DEADBAND_COUNT        (*(reg8 *) DPWM_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define DPWM_DEADBAND_COUNT_PTR     ((reg8 *) DPWM_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define DPWM_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << DPWM_DEADBAND_COUNT_SHIFT) 
        /* As defined by the verilog implementation of the Control Register */
        #define DPWM_DEADBAND_COUNT_SHIFT   0x00u 
    #endif /* (DPWM_UsingFixedFunction) */
#endif /* (DPWM_DeadBandMode == DPWM__B_PWM__DBM_256_CLOCKS) */



#if (DPWM_UsingFixedFunction)
    #define DPWM_STATUS                (*(reg8 *) DPWM_PWMHW__SR0)
    #define DPWM_STATUS_PTR            ((reg8 *) DPWM_PWMHW__SR0)
    #define DPWM_STATUS_MASK           (*(reg8 *) DPWM_PWMHW__SR0)
    #define DPWM_STATUS_MASK_PTR       ((reg8 *) DPWM_PWMHW__SR0)
    #define DPWM_CONTROL               (*(reg8 *) DPWM_PWMHW__CFG0)
    #define DPWM_CONTROL_PTR           ((reg8 *) DPWM_PWMHW__CFG0)    
    #define DPWM_CONTROL2              (*(reg8 *) DPWM_PWMHW__CFG1)    
    #define DPWM_CONTROL3              (*(reg8 *) DPWM_PWMHW__CFG2)
    #define DPWM_GLOBAL_ENABLE         (*(reg8 *) DPWM_PWMHW__PM_ACT_CFG)
    #define DPWM_GLOBAL_ENABLE_PTR       ( (reg8 *) DPWM_PWMHW__PM_ACT_CFG)
    #define DPWM_GLOBAL_STBY_ENABLE      (*(reg8 *) DPWM_PWMHW__PM_STBY_CFG)
    #define DPWM_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) DPWM_PWMHW__PM_STBY_CFG)
  
  
    /***********************************
    *          Constants
    ***********************************/

    /* Fixed Function Block Chosen */
    #define DPWM_BLOCK_EN_MASK          DPWM_PWMHW__PM_ACT_MSK
    #define DPWM_BLOCK_STBY_EN_MASK     DPWM_PWMHW__PM_STBY_MSK 
    /* Control Register definitions */
    #define DPWM_CTRL_ENABLE_SHIFT      0x00u
    
    #define DPWM_CTRL_CMPMODE1_SHIFT    0x04u  /* As defined by Register map as MODE_CFG bits in CFG2*/
    
    #define DPWM_CTRL_DEAD_TIME_SHIFT   0x06u   /* As defined by Register map */

    /* Fixed Function Block Only CFG register bit definitions */
    #define DPWM_CFG0_MODE              0x02u   /*  Set to compare mode */
    
    /* #define DPWM_CFG0_ENABLE            0x01u */  /* Enable the block to run */
    #define DPWM_CFG0_DB                0x20u   /* As defined by Register map as DB bit in CFG0 */

    /* Control Register Bit Masks */
    #define DPWM_CTRL_ENABLE            (uint8)((uint8)0x01u << DPWM_CTRL_ENABLE_SHIFT)
    #define DPWM_CTRL_RESET             (uint8)((uint8)0x01u << DPWM_CTRL_RESET_SHIFT)
    #define DPWM_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << DPWM_CTRL_CMPMODE2_SHIFT)
    #define DPWM_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << DPWM_CTRL_CMPMODE1_SHIFT)
    
    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define DPWM_CTRL2_IRQ_SEL_SHIFT    0x00u       
    #define DPWM_CTRL2_IRQ_SEL          (uint8)((uint8)0x01u << DPWM_CTRL2_IRQ_SEL_SHIFT)  
    
    /* Status Register Bit Locations */
    #define DPWM_STATUS_TC_SHIFT            0x07u   /* As defined by Register map as TC in SR0 */
    #define DPWM_STATUS_CMP1_SHIFT          0x06u   /* As defined by the Register map as CAP_CMP in SR0 */
    
    /* Status Register Interrupt Enable Bit Locations */
    #define DPWM_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)    
    #define DPWM_STATUS_TC_INT_EN_MASK_SHIFT            (DPWM_STATUS_TC_SHIFT - 4u)
    #define DPWM_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)  
    #define DPWM_STATUS_CMP1_INT_EN_MASK_SHIFT          (DPWM_STATUS_CMP1_SHIFT - 4u)
    
    /* Status Register Bit Masks */
    #define DPWM_STATUS_TC              (uint8)((uint8)0x01u << DPWM_STATUS_TC_SHIFT)
    #define DPWM_STATUS_CMP1            (uint8)((uint8)0x01u << DPWM_STATUS_CMP1_SHIFT)
    
    /* Status Register Interrupt Bit Masks */
    #define DPWM_STATUS_TC_INT_EN_MASK              (uint8)((uint8)DPWM_STATUS_TC >> 4u)
    #define DPWM_STATUS_CMP1_INT_EN_MASK            (uint8)((uint8)DPWM_STATUS_CMP1 >> 4u)
    
    /*RT1 Synch Constants */
    #define DPWM_RT1_SHIFT             0x04u
    #define DPWM_RT1_MASK              (uint8)((uint8)0x03u << DPWM_RT1_SHIFT)/* Sync TC and CMP bit masks */
    #define DPWM_SYNC                  (uint8)((uint8)0x03u << DPWM_RT1_SHIFT)
    #define DPWM_SYNCDSI_SHIFT         0x00u
    #define DPWM_SYNCDSI_MASK          (uint8)((uint8)0x0Fu << DPWM_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    #define DPWM_SYNCDSI_EN            (uint8)((uint8)0x0Fu << DPWM_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    

#else
    #define DPWM_STATUS                (*(reg8 *) DPWM_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define DPWM_STATUS_PTR            ((reg8 *) DPWM_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define DPWM_STATUS_MASK           (*(reg8 *) DPWM_PWMUDB_genblk8_stsreg__MASK_REG)
    #define DPWM_STATUS_MASK_PTR       ((reg8 *) DPWM_PWMUDB_genblk8_stsreg__MASK_REG)
    #define DPWM_STATUS_AUX_CTRL       (*(reg8 *) DPWM_PWMUDB_genblk8_stsreg__STATUS_AUX_CTL_REG)
    #define DPWM_CONTROL               (*(reg8 *) DPWM_PWMUDB_genblk1_ctrlreg__CONTROL_REG)
    #define DPWM_CONTROL_PTR           ((reg8 *) DPWM_PWMUDB_genblk1_ctrlreg__CONTROL_REG)
    
    
    /***********************************
    *          Constants
    ***********************************/

    /* Control Register definitions */
    #define DPWM_CTRL_ENABLE_SHIFT      0x07u
    #define DPWM_CTRL_RESET_SHIFT       0x06u
    #define DPWM_CTRL_CMPMODE2_SHIFT    0x03u
    #define DPWM_CTRL_CMPMODE1_SHIFT    0x00u
    #define DPWM_CTRL_DEAD_TIME_SHIFT   0x00u   /* No Shift Needed for UDB block */
    /* Control Register Bit Masks */
    #define DPWM_CTRL_ENABLE            (uint8)((uint8)0x01u << DPWM_CTRL_ENABLE_SHIFT)
    #define DPWM_CTRL_RESET             (uint8)((uint8)0x01u << DPWM_CTRL_RESET_SHIFT)
    #define DPWM_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << DPWM_CTRL_CMPMODE2_SHIFT)
    #define DPWM_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << DPWM_CTRL_CMPMODE1_SHIFT) 
    
    /* Status Register Bit Locations */
    #define DPWM_STATUS_KILL_SHIFT          0x05u
    #define DPWM_STATUS_FIFONEMPTY_SHIFT    0x04u
    #define DPWM_STATUS_FIFOFULL_SHIFT      0x03u  
    #define DPWM_STATUS_TC_SHIFT            0x02u
    #define DPWM_STATUS_CMP2_SHIFT          0x01u
    #define DPWM_STATUS_CMP1_SHIFT          0x00u
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define DPWM_STATUS_KILL_INT_EN_MASK_SHIFT          DPWM_STATUS_KILL_SHIFT          
    #define DPWM_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    DPWM_STATUS_FIFONEMPTY_SHIFT    
    #define DPWM_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      DPWM_STATUS_FIFOFULL_SHIFT        
    #define DPWM_STATUS_TC_INT_EN_MASK_SHIFT            DPWM_STATUS_TC_SHIFT            
    #define DPWM_STATUS_CMP2_INT_EN_MASK_SHIFT          DPWM_STATUS_CMP2_SHIFT          
    #define DPWM_STATUS_CMP1_INT_EN_MASK_SHIFT          DPWM_STATUS_CMP1_SHIFT   
    /* Status Register Bit Masks */
    #define DPWM_STATUS_KILL            (uint8)((uint8)0x00u << DPWM_STATUS_KILL_SHIFT )
    #define DPWM_STATUS_FIFOFULL        (uint8)((uint8)0x01u << DPWM_STATUS_FIFOFULL_SHIFT)
    #define DPWM_STATUS_FIFONEMPTY      (uint8)((uint8)0x01u << DPWM_STATUS_FIFONEMPTY_SHIFT)
    #define DPWM_STATUS_TC              (uint8)((uint8)0x01u << DPWM_STATUS_TC_SHIFT)
    #define DPWM_STATUS_CMP2            (uint8)((uint8)0x01u << DPWM_STATUS_CMP2_SHIFT) 
    #define DPWM_STATUS_CMP1            (uint8)((uint8)0x01u << DPWM_STATUS_CMP1_SHIFT)
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define DPWM_STATUS_KILL_INT_EN_MASK            DPWM_STATUS_KILL
    #define DPWM_STATUS_FIFOFULL_INT_EN_MASK        DPWM_STATUS_FIFOFULL
    #define DPWM_STATUS_FIFONEMPTY_INT_EN_MASK      DPWM_STATUS_FIFONEMPTY
    #define DPWM_STATUS_TC_INT_EN_MASK              DPWM_STATUS_TC
    #define DPWM_STATUS_CMP2_INT_EN_MASK            DPWM_STATUS_CMP2
    #define DPWM_STATUS_CMP1_INT_EN_MASK            DPWM_STATUS_CMP1
                                                          
    /* Datapath Auxillary Control Register definitions */
    #define DPWM_AUX_CTRL_FIFO0_CLR     0x01u
    #define DPWM_AUX_CTRL_FIFO1_CLR     0x02u
    #define DPWM_AUX_CTRL_FIFO0_LVL     0x04u
    #define DPWM_AUX_CTRL_FIFO1_LVL     0x08u
    #define DPWM_STATUS_ACTL_INT_EN_MASK  0x10u /* As defined for the ACTL Register */
#endif /* DPWM_UsingFixedFunction */

#endif  /* CY_PWM_DPWM_H */


/* [] END OF FILE */
