/*******************************************************************************
* File Name: cmp.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "cmp.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 cmp__PORT == 15 && ((cmp__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: cmp_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void cmp_Write(uint8 value) 
{
    uint8 staticBits = (cmp_DR & (uint8)(~cmp_MASK));
    cmp_DR = staticBits | ((uint8)(value << cmp_SHIFT) & cmp_MASK);
}


/*******************************************************************************
* Function Name: cmp_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  cmp_DM_STRONG     Strong Drive 
*  cmp_DM_OD_HI      Open Drain, Drives High 
*  cmp_DM_OD_LO      Open Drain, Drives Low 
*  cmp_DM_RES_UP     Resistive Pull Up 
*  cmp_DM_RES_DWN    Resistive Pull Down 
*  cmp_DM_RES_UPDWN  Resistive Pull Up/Down 
*  cmp_DM_DIG_HIZ    High Impedance Digital 
*  cmp_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void cmp_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(cmp_0, mode);
}


/*******************************************************************************
* Function Name: cmp_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro cmp_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 cmp_Read(void) 
{
    return (cmp_PS & cmp_MASK) >> cmp_SHIFT;
}


/*******************************************************************************
* Function Name: cmp_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 cmp_ReadDataReg(void) 
{
    return (cmp_DR & cmp_MASK) >> cmp_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(cmp_INTSTAT) 

    /*******************************************************************************
    * Function Name: cmp_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 cmp_ClearInterrupt(void) 
    {
        return (cmp_INTSTAT & cmp_MASK) >> cmp_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
