/*******************************************************************************
* File Name: mclk.h
* Version 2.20
*
*  Description:
*   Provides the function and constant definitions for the clock component.
*
*  Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_CLOCK_mclk_H)
#define CY_CLOCK_mclk_H

#include <cytypes.h>
#include <cyfitter.h>


/***************************************
* Conditional Compilation Parameters
***************************************/

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component cy_clock_v2_20 requires cy_boot v3.0 or later
#endif /* (CY_PSOC5LP) */


/***************************************
*        Function Prototypes
***************************************/

void mclk_Start(void) ;
void mclk_Stop(void) ;

#if(CY_PSOC3 || CY_PSOC5LP)
void mclk_StopBlock(void) ;
#endif /* (CY_PSOC3 || CY_PSOC5LP) */

void mclk_StandbyPower(uint8 state) ;
void mclk_SetDividerRegister(uint16 clkDivider, uint8 restart) 
                                ;
uint16 mclk_GetDividerRegister(void) ;
void mclk_SetModeRegister(uint8 modeBitMask) ;
void mclk_ClearModeRegister(uint8 modeBitMask) ;
uint8 mclk_GetModeRegister(void) ;
void mclk_SetSourceRegister(uint8 clkSource) ;
uint8 mclk_GetSourceRegister(void) ;
#if defined(mclk__CFG3)
void mclk_SetPhaseRegister(uint8 clkPhase) ;
uint8 mclk_GetPhaseRegister(void) ;
#endif /* defined(mclk__CFG3) */

#define mclk_Enable()                       mclk_Start()
#define mclk_Disable()                      mclk_Stop()
#define mclk_SetDivider(clkDivider)         mclk_SetDividerRegister(clkDivider, 1u)
#define mclk_SetDividerValue(clkDivider)    mclk_SetDividerRegister((clkDivider) - 1u, 1u)
#define mclk_SetMode(clkMode)               mclk_SetModeRegister(clkMode)
#define mclk_SetSource(clkSource)           mclk_SetSourceRegister(clkSource)
#if defined(mclk__CFG3)
#define mclk_SetPhase(clkPhase)             mclk_SetPhaseRegister(clkPhase)
#define mclk_SetPhaseValue(clkPhase)        mclk_SetPhaseRegister((clkPhase) + 1u)
#endif /* defined(mclk__CFG3) */


/***************************************
*             Registers
***************************************/

/* Register to enable or disable the clock */
#define mclk_CLKEN              (* (reg8 *) mclk__PM_ACT_CFG)
#define mclk_CLKEN_PTR          ((reg8 *) mclk__PM_ACT_CFG)

/* Register to enable or disable the clock */
#define mclk_CLKSTBY            (* (reg8 *) mclk__PM_STBY_CFG)
#define mclk_CLKSTBY_PTR        ((reg8 *) mclk__PM_STBY_CFG)

/* Clock LSB divider configuration register. */
#define mclk_DIV_LSB            (* (reg8 *) mclk__CFG0)
#define mclk_DIV_LSB_PTR        ((reg8 *) mclk__CFG0)
#define mclk_DIV_PTR            ((reg16 *) mclk__CFG0)

/* Clock MSB divider configuration register. */
#define mclk_DIV_MSB            (* (reg8 *) mclk__CFG1)
#define mclk_DIV_MSB_PTR        ((reg8 *) mclk__CFG1)

/* Mode and source configuration register */
#define mclk_MOD_SRC            (* (reg8 *) mclk__CFG2)
#define mclk_MOD_SRC_PTR        ((reg8 *) mclk__CFG2)

#if defined(mclk__CFG3)
/* Analog clock phase configuration register */
#define mclk_PHASE              (* (reg8 *) mclk__CFG3)
#define mclk_PHASE_PTR          ((reg8 *) mclk__CFG3)
#endif /* defined(mclk__CFG3) */


/**************************************
*       Register Constants
**************************************/

/* Power manager register masks */
#define mclk_CLKEN_MASK         mclk__PM_ACT_MSK
#define mclk_CLKSTBY_MASK       mclk__PM_STBY_MSK

/* CFG2 field masks */
#define mclk_SRC_SEL_MSK        mclk__CFG2_SRC_SEL_MASK
#define mclk_MODE_MASK          (~(mclk_SRC_SEL_MSK))

#if defined(mclk__CFG3)
/* CFG3 phase mask */
#define mclk_PHASE_MASK         mclk__CFG3_PHASE_DLY_MASK
#endif /* defined(mclk__CFG3) */

#endif /* CY_CLOCK_mclk_H */


/* [] END OF FILE */
